@@ -23,8 +23,8 @@ try:
 
     FABIO_EXISTS = True
 except ImportError:
-    print("Missing fabio module. Please install it if you need open some tiff images "
-            "from the sCMOS camera")
+    # print("Missing fabio module. Please install it if you need open some tiff images "
+    #         "from the sCMOS camera")
     FABIO_EXISTS = False
 
 try:
@@ -33,7 +33,7 @@ try:
     libtiff_ctypes.suppress_warnings()
     LIBTIFF_EXISTS = True
 except (ImportError, ValueError):
-    print("Missing library libtiff, Please install: pylibtiff if you need open some tiff images")
+    # print("Missing library libtiff, Please install: pylibtiff if you need open some tiff images")
     LIBTIFF_EXISTS = False
 
 try:
@@ -41,8 +41,8 @@ try:
 
     PIL_EXISTS = True
 except ImportError:
-    print("Missing python module called PIL. Please install it if you need open some tiff "
-            "images from vhr camera")
+    # print("Missing python module called PIL. Please install it if you need open some tiff "
+    #         "images from vhr camera")
     PIL_EXISTS = False
 import numpy as np
 
@@ -700,12 +700,14 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
     elif fliprot == "Imagestar_dia_2021":  # starting Feb july 2021 close to diamond monochromator crystal
         dataimage = np.rot90(dataimage, k=1)
         dataimage = np.fliplr(dataimage)
-
     elif fliprot == "frelon2":
         dataimage = np.flipud(dataimage)
-
     return dataimage, framedim, fliprot
 
+def readCCDimagev1(filename):
+    img = fabio.open(filename)
+    return img.data
+
 def getfilesize(dirname,filename):
     if dirname is not None:
         filesize = os.path.getsize(os.path.join(dirname, filename))
